package com.ruoyi.web.modules.industryservice.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Param;
import com.ruoyi.web.modules.industryservice.domain.BizGrasslandUsageRecord;

/**
 * 草场使用记录 Mapper
 */
public interface BizGrasslandUsageRecordMapper
{
    BizGrasslandUsageRecord selectBizGrasslandUsageRecordById(Long id);

    List<BizGrasslandUsageRecord> selectBizGrasslandUsageRecordList(BizGrasslandUsageRecord query);

    int insertBizGrasslandUsageRecord(BizGrasslandUsageRecord row);

    int updateBizGrasslandUsageRecord(BizGrasslandUsageRecord row);

    int logicDeleteBizGrasslandUsageRecordByIds(@Param("ids") Long[] ids, @Param("updateBy") String updateBy);
}
